<?php

require_once 'base/GepSolicitacaoEntityBase.php';

/**
 * This class has been auto-generated by Setforms
 *
 * @package Entity
 * @author  Setforms
 */
class GepSolicitacaoEntity extends GepSolicitacaoEntityBase
{


    const SIM = 'S';
    const SEM_REGISTRO = 10;


    /**
     * Retorna o pr?ximo c?digo novo da solicita??o.
     *
     * @param integer $nrorg  N?mero da Organiza??o.
     * @param integer $filial C?digo da filial.
     *
     * @return Ambigous <number, number>
     */
    public static function retornaProxNumeroSoliserv($nrorg, $filial){
        $codigo = Novocodigo::geraCodigo($nrorg, 'SOLISERV'.$filial, 10);
        return $codigo;
    }


    /**      ok
     * Retorna dados de uma determinada solicitacao.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @return Ambigous <boolean, <type>, multitype:, mixed>
     */
    public function retornaDadosSolicitacao($nrorg, $solicitacao){
        $dados = GepSolicitacao::consultaSolicitacao($nrorg, $solicitacao);

        if ($dados instanceof GepSolicitacaoEntity) {
            return $dados;
        }

        throw new Exception('GepSolicitacaoEntity1: Nao ha registro com este numero de solicitacao', self::SEM_REGISTRO);
    }


    /**
     * Retorna dados de uma determinada solicita??o.
     *
     * @param integer $nrorg       N?mero da organiza??o.
     * @param integer $solicitacao N?mero da solicita??o.
     *
     * @return Ambigous <boolean, <type>, multitype:, mixed>
     */
    public function retornaExistenciaSolicitacao($nrorg, $solicitacao){
        $dados = GepSolicitacao::consultaExistenciaSolicitacao($nrorg, $solicitacao);
        return $dados;
    }


    /**
     * Retorna dados de uma determinada solicita??o.
     *
     * @param integer $nrorg         N?mero da organiza??o.
     * @param integer $nrsolicitacao N?mero da solicita??o.
     *
     * @return Ambigous <boolean, <type>, multitype:, mixed>
     */
    public function retornaNomeSolicitacao($nrorg, $nrsolicitacao){
        $dados = GepSolicitacao::consultaNomeSolicitacao($nrorg, $nrsolicitacao);
        return $dados;
    }


    /**     ok
     * Atualza tipo e situacao de uma solicitacao.
     *
     * @param integer $nrorg          Numero da Organziacao.
     * @param integer $filial         Codigo da filial.
     * @param integer $solicitacao    Numero da solicitacao que sera atualiada.
     * @param integer $tipo_soli      Tipo da solicitacao.
     * @param integer $situacao       Numero da Situacao.
     * @param integer $parceiro       Codigo do parceiro.
     * @param integer $grupo          Grupo responsavel (perfil de acesso).
     * @param string  $idencerramento Id de encerramento da solicitacao.
     * @param string  $encerrado_por  Codigo do opperador que encerrou a solicitacao.
     * @param string  $encerrado_em   Data de encerramento.
     *
     * @return boolean
     */
    public function atualizaSolicitacao(
        $nrorg, $filial, $solicitacao, $tipo_soli, $situacao,
        $parceiro, $grupo, $idencerramento, $encerrado_por=null, $encerrado_em=null
    ){
        try {
            $lista_Solicitacao = GepSolicitacao::getObjectsByWhere(
                'NRORG = ? AND CDFILIAL = ? AND NRSOLICITACAO = ?',
                array(
                 $nrorg,
                 $filial,
                 $solicitacao,
                )
            );

            foreach ($lista_Solicitacao as $soli) {
                $soli->setNrtiposolicitacao($tipo_soli);
                $soli->setNrsituacao($situacao);
                $soli->setNrparcoperresp($parceiro);
                $soli->setNrperfilacessoresp($grupo);
                $soli->setIdsoliencerrada($idencerramento);
                $soli->setNrparcoperence($encerrado_por);
                $soli->setDtencerramentosoli($encerrado_em);
                $soli->persist();
            }

            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


    /**
     * Atualiza um campo de encerramento da solicita??o.
     *
     * @param integer $nrorg       N?mero da Organiza??o.
     * @param integer $filial      C?digo da filial.
     * @param integer $solicitacao N?mero da solicita??o.
     * @param integer $parceiro    Parceiro.
     * @param date    $data        Data de atualiza??o.
     *
     * @return boolean
     */
    public function atualizaEncerramentoSoli(
        $nrorg, $filial, $solicitacao, $parceiro, $data
    ){
        $lista_Solicitacao = GepSolicitacao::getObjectsByWhere(
            'NRORG = ? AND CDFILIAL = ? AND NRSOLICITACAO = ?',
            array(
             $nrorg,
             $filial,
             $solicitacao,
            )
        );

        foreach ($lista_Solicitacao as $soli) {
            $soli->setIdsoliencerrada(self::SIM);
            $soli->setNrparcoperence($parceiro);
            $soli->setDtencerramentosoli($data);
            $soli->persist();
        }

        return true;
    }


    /**
     * Retorna ultimo codigo de dependencia ja cadastrado.
     *
     * @param integer $nrorg N?mero da Organiza??o.
     *
     * @return Ambigous <multitype:, boolean, multitype:>
     */
    public function ultimoCodigoDependencia($nrorg){
        $codigo = GepSolicitacao::ultimoCodigoDependencia($nrorg);
        return $codigo;
    }


    /**    ok
     * Atualiza o campo de dependencia da solicitacao de uma organizacao e filial.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $filial      Codigo da Filial.
     * @param integer $solicitacao Numero da Solicicao.
     * @param integer $grupo       Numero do grupo.
     * @param integer $operador    Codigo do Operador que atualiza a solicitacao.
     * @param integer $data        Data de alteracao.
     *
     * @return boolean
     */
    public function atualizaDependenciaSoli($nrorg, $filial, $solicitacao, $grupo, $operador, $data){
        try {
            $lista_soli = GepSolicitacao::getObjectsByWhere(
                'NRORG = ? AND CDFILIAL = ? AND NRSOLICITACAO = ?',
                array(
                 $nrorg,
                 $filial,
                 $solicitacao,
                )
            );

            foreach ($lista_soli as $soli) {
                $soli->setNrgrupodependencia($grupo);
                $soli->setNrorgultatu($nrorg);
                $soli->setCdoperultatu($operador);
                $soli->setDtultatu($data);
                $soli->persist();
            }

            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


    /**      ok
     * Retorna o SQL para a tabQuery de Dependencia entre as Solicitacoes.
     *
     * @param integer $nrorg Numero da Organizacao.
     * @param integer $grupo Numero do grupo de dependencia.
     *
     * @return string
     */
    public static function retornaSqlDependentes($nrorg, $grupo){
        $sql = GepSolicitacao::retornaSqlDependentes($nrorg, $grupo);
        return $sql;
    }


    /**     ok
     * Retorna dados de uma solicitacao por grupo.
     *
     * @param integer $nrorg  Numero da Organizacao.
     * @param integer $filial Codigo da Filial.
     * @param integer $grupo  Numero do Grupo.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public function retornaSolicitacaoPorGrupo($nrorg, $filial, $grupo){
        $dados = GepSolicitacao::retornaSolicitacaoPorGrupo($nrorg, $filial, $grupo);

        if (is_array($dados) === true) {
            return $dados;
        } else {
            return false;
        }
    }


    /**
     * Retorna query para a tab de solicitacao.
     *
     * @param integer $nrorg    Numero da organizacao.
     * @param integer $filial   Codigo da filial.
     * @param integer $parceiro Codigo do parceiro.
     *
     * @return string
     */
    public function retornaSqlTabSoli($nrorg, $filial, $parceiro, $entregasoli, $tiposfluxo){
        $sql = GepSolicitacao::retornaSqlTabSolicitacao($nrorg, $filial, $parceiro, $entregasoli, $tiposfluxo);
        return $sql;
    }


    /**   ok
     * Retorna as solicitacao criadas por um determinado operador.
     *
     * @param integer $nrorg    Numero da Organizacao.
     * @param integer $operador Codigo do Operador.
     *
     * @return Ambigous <multitype:, boolean, multitype:>
     */
    public function retornaSoliPorOperInclusao($nrorg, $operador){
        $dados = GepSolicitacao::retornaSoliPorOperInclusao($nrorg, $operador);

        if ($dados instanceof GepSolicitacaoEntity) {
            return $dados;
        }

        return false;
    }


    /**     ok
     * Retorna a query para tela de atividade da solicita??a.
     *
     * @param integer $nrorg       N?mero da Organiza??o.
     * @param integer $solicitacao N?mero da Solicita??o.
     *
     * @return string
     */
    public static function retornaSqlAtividadeSoli($nrorg, $solicitacao){
        $query = GepSolicitacao::retornaSqlAtividadeSoli($nrorg, $solicitacao);
        return $query;
    }


    /**
     * Retorna proximo codigo para solicitacao de acordo com o max na tabela.
     *
     * @param integer $nrorg Numero da organizacao.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public static function retornaProximoCodigoSoli($nrorg){
        $codigo = GepSolicitacao::ultimoCodigoSolicitacao($nrorg);
        return ++$codigo;
    }


    /**    ok
     * Retorna a query para o search das solicitacoes disponiveis para dependencia.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $filial      Codigo da filial.
     * @param integer $fluxo       Tipo de fluxo.
     * @param integer $solicitacao Codigo da solicitacao.
     *
     * @return string
     */
    public static function retornaQuerySoliDependentes($nrorg, $filial, $fluxo, $solicitacao){
        $query = GepSolicitacao::retornaQuerySoliDependentes($nrorg, $filial, $fluxo, $solicitacao);
        return $query;
    }

    /**    ok
     * Retorna o numero de dependentes de um determinado grupo.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $grupo       Numero do grupo.
     *
     * @return integer
     */
    public function retornaNumDependentes($nrorg, $grupo){
        $total = GepSolicitacao::retornaNumDependentes($nrorg, $grupo);
        return $total;
    }
    
    
     /**
     * * DANIELLE
     * Retorna solicitacoes para uma atividade.
     *
     * @param  integer $nrorg Numero de organizacao.
     *
     * @return string  $query Query da consulta.
     */
        public static function retornaSolicitacaoParaAtividade(){
        $consulta = GepSolicitacao::consultaSolicitacaoParaAtividade();
        return $consulta;
    }
}